import { HeaderConfig } from './config';
/**
 * A function that allows configuring the header micro-frontend with name and templateOptions.
 *
 * @remarks
 * Configure the Header micro frontend for host app integration.
 *
 * @example Providing template options to align to your host application.
 * ```ts
 *   const { configure } = await import('@genesislcap/foundation-header/config'); // < import from the subpath
 *   return configure({
 *     name: `nexus-app-header`,
 *     // These will be merged with the packages `defaultTemplateOptions`. You will need to have these components registered in your application.
 *     templateOptions: {
 *       button: 'nexus-button',
 *       icon: 'nexus-icon-next',
 *     },
 *   });
 * },
 * ```
 *
 * @param config - A partial HeaderConfig.
 * @public
 */
export declare function configure(config: Partial<HeaderConfig>): Promise<typeof import("../main").Navigation>;
//# sourceMappingURL=configure.d.ts.map